Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8066)

Unified Diff: chrome/browser/ui/autofill/autofill_popup_view.h

Issue 2727233003: Uses child views in Autofill Popup so we can trigger (Closed)
Patch Set: (int) to NSInteger Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/autofill_popup_view.h
diff --git a/chrome/browser/ui/autofill/autofill_popup_view.h b/chrome/browser/ui/autofill/autofill_popup_view.h
index 4bb752fe467bf8df3249916f09268fbc35640c29..86251e652f4ce873d1caf137cd2a3aeaaf7ef2a2 100644
--- a/chrome/browser/ui/autofill/autofill_popup_view.h
+++ b/chrome/browser/ui/autofill/autofill_popup_view.h
@@ -7,6 +7,7 @@
#include <stddef.h>
+#include "base/optional.h"
#include "base/strings/string16.h"
#include "chrome/browser/ui/autofill/autofill_popup_view_delegate.h"
@@ -24,11 +25,13 @@ class AutofillPopupView {
// Hides the popup from view. This will cause the popup to be deleted.
virtual void Hide() = 0;
- // Invalidates the given row and redraw it.
- virtual void InvalidateRow(size_t row) = 0;
+ // If not null, invalidates the given rows and redraws them.
+ virtual void OnSelectedRowChanged(
+ base::Optional<int> previous_row_selection,
+ base::Optional<int> current_row_selection) = 0;
- // Refreshes the position of the popup.
- virtual void UpdateBoundsAndRedrawPopup() = 0;
+ // Refreshes the position and redraws popup when suggestions change.
+ virtual void OnSuggestionsChanged() = 0;
// Factory function for creating the view.
static AutofillPopupView* Create(AutofillPopupController* controller);

Powered by Google App Engine
This is Rietveld 408576698